==> apache-camel-quarkus-3.15.4-src.zip: camel-quarkus-3.15.4/test-framework/junit5/src/main/java/org/apache/camel/quarkus/test/AfterAllCallback.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.test;

import io.quarkus.test.junit.callback.QuarkusTestAfterAllCallback;
import io.quarkus.test.junit.callback.QuarkusTestContext;
import org.junit.jupiter.api.extension.ExtensionContext;

public class AfterAllCallback implements QuarkusTestAfterAllCallback {

    @Override
    public void afterAll(QuarkusTestContext context) {
        if (context.getTestInstance() instanceof CamelQuarkusTestSupport) {
            CamelQuarkusTestSupport testInstance = (CamelQuarkusTestSupport) context.getTestInstance();

            if (CallbackUtil.isPerClass(testInstance)) {
                ExtensionContext mockContext = new CallbackUtil.MockExtensionContext(CallbackUtil.getLifecycle(testInstance),
                        null);

                testInstance.internalAfterAll(context, mockContext);
                CallbackUtil.resetContext(testInstance);
            }

            try {
                testInstance.doAfterAll(context);
            } catch (Exception e) {
                throw new RuntimeException(e);
            }
        }
    }
}

==> apache-camel-quarkus-3.27.0-src.zip: camel-quarkus-3.27.0/test-framework/junit5/src/main/java/org/apache/camel/quarkus/test/AfterAllCallback.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.test;

import io.quarkus.test.junit.callback.QuarkusTestAfterAllCallback;
import io.quarkus.test.junit.callback.QuarkusTestContext;

public class AfterAllCallback implements QuarkusTestAfterAllCallback {

    @Override
    public void afterAll(QuarkusTestContext context) {
        if (context.getTestInstance() instanceof CamelQuarkusTestSupport) {
            CamelQuarkusTestSupport testInstance = (CamelQuarkusTestSupport) context.getTestInstance();

            if (CallbackUtil.isPerClass(testInstance)) {
                testInstance.internalAfterAll();
                CallbackUtil.resetContext(testInstance);
            }

            try {
                testInstance.doAfterAll(context);
            } catch (Exception e) {
                throw new RuntimeException(e);
            }
        }
    }
}
